#ifdef GL_FRAGMENT_PRECISION_HIGH
    precision highp float;
#else
    precision mediump float;
#endif

uniform sampler2D u_TextureY;
uniform sampler2D u_TextureV;
uniform sampler2D u_TextureU;

uniform vec2 u_Resolution;
uniform float u_CircleRadius;
uniform vec2 u_CirclePos;
uniform vec3 u_ringColor;
uniform float u_viewScale;
uniform vec3 u_WidthScaleFactor;

varying vec2 v_TexCoordinate;
varying vec2 v_CircleCoordinate;

const mat3 yuv2rgb = mat3(
  1,              1,      1,
  0,       -0.18732, 1.8556,
  1.57481, -0.46813,      0);

const vec4 transparent = vec4(0.0);

const float halfPixelRadius = 0.0005; // 0.5 pixel / 1000 as the uniforms are scaled by 1/1000
const float ringWidthRatio = 0.002;

void main() {

    float ringWidth = ringWidthRatio * min(u_Resolution.x, u_Resolution.y) / u_viewScale;
    float innerRadius = u_CircleRadius - ringWidth;

    float distanceToCenter = distance(v_CircleCoordinate, u_CirclePos);

    float viewScaledHalfPixelRadius = halfPixelRadius / u_viewScale;
    float alpha1 = smoothstep(innerRadius - viewScaledHalfPixelRadius, innerRadius + viewScaledHalfPixelRadius, distanceToCenter);
    float alpha2 = smoothstep(u_CircleRadius - viewScaledHalfPixelRadius, u_CircleRadius + viewScaledHalfPixelRadius, distanceToCenter);

    // Sample from camera texture.
    vec3 yuv = vec3(texture2D(u_TextureY, v_TexCoordinate * vec2(u_WidthScaleFactor.x, 1.0)).r,
                    texture2D(u_TextureU, v_TexCoordinate * vec2(u_WidthScaleFactor.y, 1.0)).r,
                    texture2D(u_TextureV, v_TexCoordinate * vec2(u_WidthScaleFactor.z, 1.0)).r);
    yuv -= vec3(0.0, 0.5, 0.5);

    // Convert to RGB color space.
    vec4 rgb = vec4(yuv2rgb * yuv, 1.0);

    gl_FragColor = mix(mix(rgb, vec4(u_ringColor, 1.0), alpha1), transparent, alpha2);
}
