#extension GL_OES_EGL_image_external : require

#ifdef GL_FRAGMENT_PRECISION_HIGH
    precision highp float;
#else
    precision mediump float;
#endif

uniform samplerExternalOES u_TextureY;

uniform vec2 u_Resolution;
uniform float u_CircleRadius;
uniform vec2 u_CirclePos;
uniform vec3 u_ringColor;
uniform float u_viewScale;

varying vec2 v_TexCoordinate;
varying vec2 v_CircleCoordinate;

const vec4 transparent = vec4(0.0);

const float halfPixelRadius = 0.0005; // 0.5 pixel / 1000 as the uniforms are scaled by 1/1000
const float ringWidthRatio = 0.002;

void main() {
    float ringWidth = ringWidthRatio * min(u_Resolution.x, u_Resolution.y) / u_viewScale;
    float innerRadius = u_CircleRadius - ringWidth;

    float distanceToCenter = distance(v_CircleCoordinate, u_CirclePos);

    float viewScaledHalfPixelRadius = halfPixelRadius / u_viewScale;
    float alpha1 = smoothstep(innerRadius - viewScaledHalfPixelRadius, innerRadius + viewScaledHalfPixelRadius, distanceToCenter);
    float alpha2 = smoothstep(u_CircleRadius - viewScaledHalfPixelRadius, u_CircleRadius + viewScaledHalfPixelRadius, distanceToCenter);

    // Sample from camera texture.
    vec4 rgb = texture2D(u_TextureY, v_TexCoordinate);
    gl_FragColor = mix(mix(rgb, vec4(u_ringColor, 1.0), alpha1), transparent, alpha2);
}
